# HB LAB

VTU AI ML LAB CODE package

## Installation

Use the package manager [pip](https://pypi.org/project/hblab/) to install HBLAB.

pip install hblab

## Usage

from hblab import lab

lab.program_code(program number)

## Creator

https://github.com/iamnyk7
